:userdoc.
:title.UNIX/XWindows Version

.*********************************************************
:h1. EULER for XWindows/UNIX
:p.
This is a short documentation of the XWindows version of EULER.
For a reference to the EULER language, look into the EULER
documentation (EULER.HTML).
.*********************************************************
:h2 res=800.Introduction
:p.
EULER for UNIX/XWindows consists (at least) of&colon.
:ul compact.
:li. xeuler (the program)
:li. euler.cfg (is loaded after the start of the program)
:li. util.e (in turn loaded from EULER.CFG)
:eul.
:p.
There are some additional *.E files. The documentation is contained in the 
*.IPF files, which are translated into HTML documents, when EULER is 
compiled. There are also notebook files with extension *.EN. You can load
these files with the notebook command.

.*********************************************************
:h2 res=810.Installation
:p.
This documentation concerns the UNIX/XWindows version of EULER.
You will have to compile the source using "make".
:p.
Implementation hints:
:p.
This version of EULER has been programmed on an IBM-RS6000 machine,
with AIX 3.1.5 and XWindows X11 Release 3. To help you solve problems
on other machines, follow these instructions. I have tested the
program on Linux and Sun.
:p.
Memory:
:p.
EULER uses a fixed portion of memory, the size of which must be
specified at program start. To do this use the "-s" command line
option. The default value is contained in the variable memsize (1
MByte) of "sysdepx.c". Change this according to your needs and
resources. Since UNIX uses demand paging, you may choose a high
and sufficient value here.
:p.
Floating point allignment:
EULER alligns floating point values on even addresses. If your machine
requires 8-Byte allignment, you should define SPECIAL_ALIGNMENT. This
is necesssary for DEC and Sun architectures.
:p.
Floating point errors:
:p.
EULER catches floating point errors, when the makro FPE is defined.
However, it is superior to use the IEEE standard floating point
extensions INF and NaN. If you have these available, do not define
FPE. Most machines do not have hardware infinity and need FPE. You
will notice, if you need it, when Euler crashes after the command
1/0.
:p.
Fonts:
:p.
EULER uses two fonts, a text and a graphics font. These fonts can be
chosen in the command line. The default fonts are set in the makefile
by makro definitions. Change this to the needs of your XWindow
version.
:p.
Timer:
:p.
EULER needs a timer for the wait function. If your machine is an
RS6000, you can use its accurate timer function. If not, undefine the
makro definition in the makefile. Then EULER will use standard UNIX
time functions.
:p.
Colors:
:p.
EULER uses colors for graphics. You can set these colors in the
command line by name. You can also change the default colors in the
file "sysdepx.c".
:p.
Directories:
:p.
You should create directories euler/source and euler/progs in your
home directory. All *.e files and euler.cfg should be in euler/progs.
The source files should be in euler/source. You should make a shell
script, which switches to the directory progs and then calls xeuler
there.
:p.
Special care has to be taken on Sun based machines. First of all, you
need an ANSI-C compiler. Most Gnu-C++ ports will suffice, but not all.
If you have it, use acc. Then you will need to define the SUN macro
in the makefile. This will make your keyboard work correctly.
:p.
The command line options accepted by EULER are
:p.

:dl tsize=20 break=fit.
:dt.-f font
:dd.sets the text font
:dt.-g font
:dd.sets the graphics font
:dt.-s Kbytes
:dd.sets the available space
:dt.-geom geometry
:dd.sets the window geometry (e.g., -geom 600x600+0+0)
:dt.-d display
:dd.sets the display
:dt.-## color
:dd.sets color ## (0 to 15) to the color name (e.g. -3 green)
:dt.-b
:dd.uses a black and white color scheme
:dt.files
:dd.are files to be loaded after EULER.CFG
:edl.
:p.

First edit the makefile according to the hints above.

To compile EULER, you type
:xmp.
    make
:exmp.:p.
in the source directory. This will create xeuler in source.
You can test it by running xeuler. You may also create a
non-graphics version with
:xmp.
    make noxeuler
:exmp.:p.
The command
:xmp.
    make install
:exmp.
then copies xeuler and noxeuler to the progs directory. You should
then create a shell script, which starts xeuler, in your $HOME/bin
file, or you can start xeuler yourself in the progs directory. There
should be a file euler.cfg, which loads the ../progs/util.e.
:p.
To create the documentation, start
:xmp.
    make html
:exmp.:p.
This will create several *.html files in the make directory, which you can
read with your Web-Browser. If you want a printed documentation, start
:xmp.
    make doc
:exmp.:p.
You can send the files docs/*.doc to your printer.
:p.
You should also issue the command
:xmp.
    >load "demo"
:exmp.
to get a good idea, what EULER can do for you.

.*********************************************************
:h2.Contact the Author

For questions, here is the EMail address of the author:
:xmp.
grothm@am.ku-eichstaett.de
rene.grothmann@ku-eichstaett.de
:exmp.:p.

and the mail address is
:xmp.
Dr. R. Grothmann
Kath. Univ. Eichstaett
D-85071 Eichstaett
Germany
:exmp.:p.

.*********************************************************
:h2 res=890.The UNIX/XWindows Interface
:p.
This interface has only a single window, which serves as text and 
graphics window. You can pop up the graphics in this window with the 
TAB key.
:p.
To print the graphics you may use the standard harcopy commands of 
XWindows. However, I am using a self made xlaser command, which 
produces better output an a HP laserjet printer.
:p.
There are some command line options available.
:dl tsize=20 break=fit.
:dt. -f font
:dd. Set the text font. You may use the asterix * as usual for
font selection. The font must be fixed width.
:dt. -g font
:dd. Set the graphics font.
:dt. -s KByte
:dd. Reserves the given number of KB EULER stack.
:dt. -geom geometry
:dd. The normal geometry settings for the window.
:dt. =geometry
:dd. Another form.
:dt. -## color
:dd. Sets color number ##. Specify the color with its name. Color 0 is
the graphic background and one the default line color.
:dt. -b
:dd. Use a black and white scheme for graphics.
:dt. filename
:dd. Load this file after the EULER.CFG file.
:edl.
The keyboard commands are more or less the same as in the OS/2 
version. However, you may use Cursor-Up without the Shift key to 
recall old commands, since this version does not support notebooks.

:euserdoc.
